using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using Footbreak.Properties;

namespace Footbreak
{
    public partial class FootbreakDialog : Form
    {
        HandbrakeCommandLine mHandbrake = new HandbrakeCommandLine( Settings.Default.HandbrakeLocation );
        Thread mHandbrakeThread;
        HandbrakeSettings mHandbrakeSettings = new HandbrakeSettings();
        AddISOWizard.WizardSheet mAddISOWizard = new Footbreak.AddISOWizard.WizardSheet();
        BackgroundWorker mHandbrakeWorker = new BackgroundWorker();

        public FootbreakDialog()
        {
            InitializeComponent();
            mHandbrake.mCompletedEvent += new EventDelegate( onHandbrakeThreadCompleted );
            mHandbrake.mAddTitleEvent += new AddTitleDelegate( onAddTitle );
            mHandbrake.mUpdatePercentEvent += new PercentDelegate( onUpdatePercent );
            mHandbrake.mUpdateStatusEvent += new StatusDelegate( onUpdateStatus );
            mHandbrake.mRemoveTitleEvent += new RemoveTitleDelegate( onRemoveTitle );
            settingsPropertyGrid.SelectedObject = mHandbrakeSettings;
            mHandbrakeWorker.DoWork += new DoWorkEventHandler( mHandbrakeWorker_DoWork );
            return;
        }

        void onRemoveTitle( HandbrakeTitle aTitle )
        {
            if ( this.InvokeRequired )
            {
                this.Invoke( new RemoveTitleDelegate( onRemoveTitle ), new object[] { aTitle } );
            }
            else
            {
                handbrakeTitleBindingSource.Remove( aTitle );
            }
        }

        void mHandbrakeWorker_DoWork( object sender, DoWorkEventArgs e )
        {
            while ( handbrakeTitleBindingSource.Count > 0 )
            {
                HandbrakeTitle lHandbrakeTitle = handbrakeTitleBindingSource[0] as HandbrakeTitle;
                this.Invoke( new RemoveTitleDelegate( onRemoveTitle ), new object[] { lHandbrakeTitle } );
                mHandbrake.convertTitle( mHandbrakeSettings, lHandbrakeTitle );
            }
            return;
        }

        void onHandbrakeThreadCompleted()
        {
            if ( convertButton.InvokeRequired )
            {
                this.Invoke( new EventDelegate( onHandbrakeThreadCompleted ) );
            }
            else
            {
                mHandbrakeThread.Abort();
                mHandbrakeThread = null;
                convertButton.Enabled = true;
                abortButton.Enabled = false;
                toolStripStatusLabel.Text = "";
                toolStripProgressBar.Value = 0;
            }
            return;
        }

        void onAddTitle( HandbrakeTitle aTitle )
        {
            if ( handbrakeTitleDataGridView.InvokeRequired )
            {
                this.Invoke( new AddTitleDelegate( onAddTitle ), new object[] { aTitle } );
            }
            else
            {
                handbrakeTitleBindingSource.Add( aTitle );
                handbrakeTitleDataGridView.Refresh();
            }
            return;
        }

        void onUpdatePercent( int aPercent )
        {
            if ( this.InvokeRequired )
            {
                this.Invoke( new PercentDelegate( onUpdatePercent ), new object[] { aPercent } );
            }
            else
            {
                toolStripProgressBar.Value = aPercent;
            }
            return;
        }

        void onUpdateStatus( string aString )
        {
            if ( this.InvokeRequired )
            {
                this.Invoke( new StatusDelegate( onUpdateStatus ), new object[] { aString } );
            }
            else
            {
                toolStripStatusLabel.Text = aString;
            }
            return;
        }

        private void addISOButton_Click( object sender, EventArgs e )
        {
            if ( mAddISOWizard.ShowDialog() == DialogResult.OK )
            {
                foreach ( HandbrakeTitle lTitle in mAddISOWizard.GetSelectedTitles() )
                {
                    onAddTitle( lTitle );
                }
            }
            /*if ( isoOpenFileDialog.ShowDialog() == DialogResult.OK )
            {
                mHandbrakeThread = new Thread( new ParameterizedThreadStart( mHandbrake.getTitles ) );
                addISOButton.Enabled = false;
                convertButton.Enabled = false;
                handbrakeTitleDataGridView.Enabled = false;
                settingsPropertyGrid.Enabled = false;
                abortButton.Enabled = true;
                mHandbrakeThread.Start( isoOpenFileDialog.FileNames );
            }*/
            return;
        }

        /*private void twoPassEncodingToolStripMenuItem_Click( object sender, EventArgs e )
        {
            twoPassEncodingToolStripMenuItem.Checked = !twoPassEncodingToolStripMenuItem.Checked;
            foreach ( HandbrakeTitle lTitle in handbrakeTitleBindingSource )
            {
                lTitle.TwoPassEncoding = twoPassEncodingToolStripMenuItem.Checked;
            }
            handbrakeTitleDataGridView.Refresh();
            return;
        }

        private void deinterlaceToolStripMenuItem_Click( object sender, EventArgs e )
        {
            deinterlaceToolStripMenuItem.Checked = !deinterlaceToolStripMenuItem.Checked;
            foreach ( HandbrakeTitle lTitle in handbrakeTitleBindingSource )
            {
                lTitle.Deinterlace = deinterlaceToolStripMenuItem.Checked;
            }
            handbrakeTitleDataGridView.Refresh();
            return;
        }*/

        private void convertButton_Click( object sender, EventArgs e )
        {
            convertButton.Enabled = false;
            abortButton.Enabled = true;
            mHandbrakeWorker.RunWorkerAsync();
            /*mHandbrakeThread = new Thread( new ParameterizedThreadStart( mHandbrake.convertTitles ) );
            convertButton.Enabled = false;
            abortButton.Enabled = true;
            Pair<HandbrakeSettings, BindingSource> lThreadData = new Pair<HandbrakeSettings, BindingSource>( mHandbrakeSettings, handbrakeTitleBindingSource );
            mHandbrakeThread.Start( lThreadData );*/
            return;
        }

        private void abortButton_Click( object sender, EventArgs e )
        {
            mHandbrake.Abort = true;
            return;
        }

        private void FootbreakDialog_FormClosing( object sender, FormClosingEventArgs e )
        {
            if ( mHandbrakeThread != null )
            {
                mHandbrake.Abort = true;
            }
            return;
        }
    }
}