using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace Footbreak
{
    public class HandbrakeSettings
    {
        public enum VideoEncoderType
        {
            ffmpeg,
            xvid,
            x264,
            x264b13,
            x264b30,
        }

        public enum AudioEncoderType
        {
            faac,
            lame,
            vorbis,
            ac3,
        }

        public enum AudioSampleRateType
        {
            rate_22_05,
            rate_24_00,
            rate_32_00,
            rate_44_10,
            rate_48_00,
        }

        public enum DeinterlaceType
        {
            None,
            Fast,
            Slow
        }

        private bool mTwoPass = true;
        private DeinterlaceType mDeinterlace = DeinterlaceType.None;
        private bool mChapterMarkers = true;
        private VideoEncoderType mVideoEncoder = VideoEncoderType.x264;
        private uint mVideoBitrate = 1000;
        private AudioEncoderType mAudioEncoder = AudioEncoderType.faac;
        private uint mAudioBitrate = 128;
        private AudioSampleRateType mAudioSampleRate = AudioSampleRateType.rate_44_10;
        private string mOutputPath = @"C:\TV\{Series Name}\Season {Season}\{Series Name} - S{Season}E{Episode Number} - {Episode Title}.mp4";

        [
        Category( "Video" ),
        Description( "Takes twice as long, but the quality may be better." )
        ]
        public bool TwoPass
        {
            get
            {
                return mTwoPass;
            }
            set
            {
                mTwoPass = value;
            }
        }

        [
        Category( "Video" ),
        Description( "Use for older TV shows that have interlaced video." )
        ]
        public DeinterlaceType Deinterlace
        {
            get
            {
                return mDeinterlace;
            }
            set
            {
                mDeinterlace = value;
            }
        }

        [
        Category( "Video" ),
        Description( "Add chapter markers (mp4 output format only)" )
        ]
        public bool ChapterMarkers
        {
            get
            {
                return mChapterMarkers;
            }
            set
            {
                mChapterMarkers = value;
            }
        }

        [
        Category( "Video" ),
        Description( "x264 = slow and good, ffmpeg = fast and fair." )
        ]
        public VideoEncoderType VideoEncoder
        {
            get
            {
                return mVideoEncoder;
            }
            set
            {
                mVideoEncoder = value;
            }
        }

        [
        Category( "Video" ),
        Description( "2000 = overkill, 1000 = good, 500 = bad" )
        ]
        public uint VideoBitrate
        {
            get
            {
                return mVideoBitrate;
            }
            set
            {
                mVideoBitrate = value;
            }
        }

        [
        Category( "Audio" ),
        Description( "Use faac or lame" )
        ]
        public AudioEncoderType AudioEncoder
        {
            get
            {
                return mAudioEncoder;
            }
            set
            {
                mAudioEncoder = value;
            }
        }

        [
        Category( "Audio" ),
        Description( "256 = overkill, 128 = good, 64 = bad" )
        ]
        public uint AudioBitrate
        {
            get
            {
                return mAudioBitrate;
            }
            set
            {
                mAudioBitrate = value;
            }
        }

        [
        Category( "Audio" ),
        Description( "48 = overkill, 44.1 = good, 32 = bad" )
        ]
        public AudioSampleRateType AudioSampleRate
        {
            get
            {
                return mAudioSampleRate;
            }
            set
            {
                mAudioSampleRate = value;
            }
        }

        [
        Category( "Output" ),
        Description( "The output path." )
        ]
        public string OutputPath
        {
            get
            {
                return mOutputPath;
            }
            set
            {
                mOutputPath = value;
            }
        }
    }
}
